require 'date'

module Supportify
  class Faq
    # Unique identifier representing a specific content entry within an application.
    attr_accessor :id

    # The body of the content entry.  Can be an answer to a FAQ, a knowledge base entry, or any other type of string.  This is a non-encoded string and may contain HTML.
    attr_accessor :answer

    attr_accessor :categories

    # A score that measures the disparity between positive and negative votes for the content entry.
    attr_accessor :controversy_score

    # The date and time that the content entry was created.
    attr_accessor :date_created

    # The date and time that the content entry was last modified.
    attr_accessor :date_last_modified

    # The total number of views that the content entry has received individually (i.e., access via the '/faqs/<id>' path.
    attr_accessor :direct_views

    # The title of the content entry.  Can be a question, a title, or any other type of string.  This is a non-encoded string and may contain HTML.
    attr_accessor :question

    # The score for the content entry within the application.  This is weighted score tabulated based on a total of up and down votes and compared against other votes for content entries in the application.
    attr_accessor :rating

    # The total number of positive votes minus the number of negative votes for the content entry.
    attr_accessor :raw_score

    # The total number of views that the content entry has received as part of a set of search results (i.e., access via the '/search' path.
    attr_accessor :search_views

    attr_accessor :tags

    # The total number of views that the content entry has received as part of a whole collection, individually, or as part of a set of search results.
    attr_accessor :total_views

    # The total number of votes that the content entry has received since it was created.
    attr_accessor :votes

    attr_accessor :was_created_by

    attr_accessor :was_last_modified_by

    # Attribute mapping from ruby-style variable name to JSON key.
    def self.attribute_map
      {
        
        :'id' => :'id',
        
        :'answer' => :'answer',
        
        :'categories' => :'categories',
        
        :'controversy_score' => :'controversy_score',
        
        :'date_created' => :'date_created',
        
        :'date_last_modified' => :'date_last_modified',
        
        :'direct_views' => :'direct_views',
        
        :'question' => :'question',
        
        :'rating' => :'rating',
        
        :'raw_score' => :'raw_score',
        
        :'search_views' => :'search_views',
        
        :'tags' => :'tags',
        
        :'total_views' => :'total_views',
        
        :'votes' => :'votes',
        
        :'was_created_by' => :'was_created_by',
        
        :'was_last_modified_by' => :'was_last_modified_by'
        
      }
    end

    # Attribute type mapping.
    def self.swagger_types
      {
        :'id' => :'Integer',
        :'answer' => :'String',
        :'categories' => :'Array<Category>',
        :'controversy_score' => :'Integer',
        :'date_created' => :'DateTime',
        :'date_last_modified' => :'DateTime',
        :'direct_views' => :'Integer',
        :'question' => :'String',
        :'rating' => :'Float',
        :'raw_score' => :'Integer',
        :'search_views' => :'Integer',
        :'tags' => :'Array<Tag>',
        :'total_views' => :'Integer',
        :'votes' => :'Integer',
        :'was_created_by' => :'User',
        :'was_last_modified_by' => :'User'
        
      }
    end

    def initialize(attributes = {})
      return unless attributes.is_a?(Hash)

      # convert string to symbol for hash key
      attributes = attributes.inject({}){|memo,(k,v)| memo[k.to_sym] = v; memo}

      
      if attributes[:'id']
        self.id = attributes[:'id']
      end
      
      if attributes[:'answer']
        self.answer = attributes[:'answer']
      end
      
      if attributes[:'categories']
        if (value = attributes[:'categories']).is_a?(Array)
          self.categories = value
        end
      end
      
      if attributes[:'controversy_score']
        self.controversy_score = attributes[:'controversy_score']
      end
      
      if attributes[:'date_created']
        self.date_created = attributes[:'date_created']
      end
      
      if attributes[:'date_last_modified']
        self.date_last_modified = attributes[:'date_last_modified']
      end
      
      if attributes[:'direct_views']
        self.direct_views = attributes[:'direct_views']
      end
      
      if attributes[:'question']
        self.question = attributes[:'question']
      end
      
      if attributes[:'rating']
        self.rating = attributes[:'rating']
      end
      
      if attributes[:'raw_score']
        self.raw_score = attributes[:'raw_score']
      end
      
      if attributes[:'search_views']
        self.search_views = attributes[:'search_views']
      end
      
      if attributes[:'tags']
        if (value = attributes[:'tags']).is_a?(Array)
          self.tags = value
        end
      end
      
      if attributes[:'total_views']
        self.total_views = attributes[:'total_views']
      end
      
      if attributes[:'votes']
        self.votes = attributes[:'votes']
      end
      
      if attributes[:'was_created_by']
        self.was_created_by = attributes[:'was_created_by']
      end
      
      if attributes[:'was_last_modified_by']
        self.was_last_modified_by = attributes[:'was_last_modified_by']
      end
      
    end

    # Check equality by comparing each attribute.
    def ==(o)
      return true if self.equal?(o)
      self.class == o.class &&
          id == o.id &&
          answer == o.answer &&
          categories == o.categories &&
          controversy_score == o.controversy_score &&
          date_created == o.date_created &&
          date_last_modified == o.date_last_modified &&
          direct_views == o.direct_views &&
          question == o.question &&
          rating == o.rating &&
          raw_score == o.raw_score &&
          search_views == o.search_views &&
          tags == o.tags &&
          total_views == o.total_views &&
          votes == o.votes &&
          was_created_by == o.was_created_by &&
          was_last_modified_by == o.was_last_modified_by
    end

    # @see the `==` method
    def eql?(o)
      self == o
    end

    # Calculate hash code according to all attributes.
    def hash
      [id, answer, categories, controversy_score, date_created, date_last_modified, direct_views, question, rating, raw_score, search_views, tags, total_views, votes, was_created_by, was_last_modified_by].hash
    end

    # build the object from hash
    def build_from_hash(attributes)
      return nil unless attributes.is_a?(Hash)
      self.class.swagger_types.each_pair do |key, type|
        if type =~ /^Array<(.*)>/i
          if attributes[self.class.attribute_map[key]].is_a?(Array)
            self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } )
          else
            #TODO show warning in debug mode
          end
        elsif !attributes[self.class.attribute_map[key]].nil?
          self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
        else
          # data not found in attributes(hash), not an issue as the data can be optional
        end
      end

      self
    end

    def _deserialize(type, value)
      case type.to_sym
      when :DateTime
        DateTime.parse(value)
      when :Date
        Date.parse(value)
      when :String
        value.to_s
      when :Integer
        value.to_i
      when :Float
        value.to_f
      when :BOOLEAN
        if value =~ /^(true|t|yes|y|1)$/i
          true
        else
          false
        end
      when /\AArray<(?<inner_type>.+)>\z/
        inner_type = Regexp.last_match[:inner_type]
        value.map { |v| _deserialize(inner_type, v) }
      when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/
        k_type = Regexp.last_match[:k_type]
        v_type = Regexp.last_match[:v_type]
        {}.tap do |hash|
          value.each do |k, v|
            hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
          end
        end
      else # model
        _model = Supportify.const_get(type).new
        _model.build_from_hash(value)
      end
    end

    def to_s
      to_hash.to_s
    end

    # to_body is an alias to to_body (backward compatibility))
    def to_body
      to_hash
    end

    # return the object in the form of hash
    def to_hash
      hash = {}
      self.class.attribute_map.each_pair do |attr, param|
        value = self.send(attr)
        next if value.nil?
        hash[param] = _to_hash(value)
      end
      hash
    end

    # Method to output non-array value in the form of hash
    # For object, use to_hash. Otherwise, just return the value
    def _to_hash(value)
      if value.is_a?(Array)
        value.compact.map{ |v| _to_hash(v) }
      elsif value.is_a?(Hash)
        {}.tap do |hash|
          value.each { |k, v| hash[k] = _to_hash(v) }
        end
      elsif value.respond_to? :to_hash
        value.to_hash
      else
        value
      end
    end

  end
end
